@@ -22,9 +22,9 @@ const our $TX_STATUS_ERROR => 'E';    # in a failed transaction block (queries w
 require Pcore::PgSQL::DBH;
 
 has max_dbh => ( is => 'ro', isa => PositiveInt, default => 3 );
-has backlog => ( is => 'ro', isa => PositiveInt, default => 1_000 );
+has backlog => ( is => 'ro', isa => Maybe [PositiveInt], default => 1_000 );
 has host     => ( is => 'lazy', isa => Str );
-has port     => ( is => 'ro',   isa => PositiveInt, default => 5432 );
+has port     => ( is => 'ro',   isa => PositiveOrZeroInt, default => 5432 );
 has username => ( is => 'lazy', isa => Str );
 has password => ( is => 'lazy', isa => Str );
 has database => ( is => 'lazy', isa => Str );
@@ -90,7 +90,7 @@ sub _get_dbh ( $self, $cb ) {
         }
     }
 
-    if ( $self->{_get_dbh_queue}->@* > $self->{backlog} ) {
+    if ( $self->{backlog} && $self->{_get_dbh_queue}->@* > $self->{backlog} ) {
         warn 'DBI: backlog queue is full';
 
         $cb->( result( [ 500, 'backlog queue is full' ] ), undef );
